@@ -20,13 +20,13 @@
 
 #include "metacontact_p.h"
 #include "personmanager_p.h"
-#include "personpluginmanager_p.h"
+#include "personpluginmanager.h"
 #include "backends/basepersonsdatasource.h"
 #include "backends/contactmonitor.h"
 #include "backends/abstractcontact.h"
 
 #include <QUrl>
-#include <QDebug>
+#include "kpeople_debug.h"
 #include <QStandardPaths>
 
 namespace KPeople
@@ -70,6 +70,7 @@ KPeople::PersonData::PersonData(const QString &id, QObject *parent):
     Q_FOREACH (const QString &contactUri, d->contactUris) {
         //load the correct data source for this contact ID
         const QString sourceId = contactUri.left(contactUri.indexOf(QStringLiteral("://")));
+        Q_ASSERT(!sourceId.isEmpty());
         BasePersonsDataSource *dataSource = PersonPluginManager::dataSource(sourceId);
         if (dataSource) {
             ContactMonitorPtr cw = dataSource->contactMonitor(contactUri);
@@ -82,7 +83,7 @@ KPeople::PersonData::PersonData(const QString &id, QObject *parent):
             }
             connect(cw.data(), SIGNAL(contactChanged()), SLOT(onContactChanged()));
         } else
-            qWarning() << "error: creating PersonData for unknown contact" << contactUri << id;
+            qCWarning(KPEOPLE_LOG) << "error: creating PersonData for unknown contact" << contactUri << id;
     }
 
     if (personUri.isEmpty() && contacts.size() == 1) {
@@ -133,7 +134,6 @@ void PersonData::onContactChanged()
 
 QPixmap PersonData::photo() const
 {
-    Q_D(const PersonData);
     QPixmap avatar;
 
     QVariant pic = contactCustomProperty(AbstractContact::PictureProperty);
@@ -157,7 +157,6 @@ QVariant PersonData::contactCustomProperty(const QString &key) const
 
 QString PersonData::presenceIconName() const
 {
-    Q_D(const PersonData);
     QString contactPresence = contactCustomProperty(QStringLiteral("telepathy-presence")).toString();
     return KPeople::iconNameForPresenceString(contactPresence);
 }
